@@ -933,7 +933,7 @@ def sigProfilerExtractor(input_type,
         
        
         # create the folder for the final solution/ De Novo Solution
-        layer_directory1 = output+"/Suggested_Solution/De_Novo_Solution"
+        layer_directory1 = output+"/Suggested_Solution/"+mutation_type+"_De_Novo_Solution"
         try:
             if not os.path.exists(layer_directory1):
                 os.makedirs(layer_directory1)
@@ -969,6 +969,8 @@ def sigProfilerExtractor(input_type,
                 os.makedirs(layer_directory2)
         except: 
             print ("The {} folder could not be created".format("output"))
+            
+        originalProcessAvg=pd.DataFrame(processAvg, index=index)
         
         if processAvg.shape[0]==1536: #collapse the 1596 context into 96 only for the deocmposition 
             processAvg = pd.DataFrame(processAvg, index=index)
@@ -988,8 +990,9 @@ def sigProfilerExtractor(input_type,
             index = genomes.index
             processAvg = np.array(processAvg)
             genomes = np.array(genomes)
-            
-        final_signatures = sub.signature_decomposition(processAvg, m, layer_directory2, genome_build=genome_build, add_penalty=add_penalty, remove_penalty=remove_penalty, mutation_context=mutation_context, make_decomposition_plots=make_decomposition_plots)
+        
+        originalProcessAvg.columns = listOfSignatures    
+        final_signatures = sub.signature_decomposition(processAvg, m, layer_directory2, genome_build=genome_build, add_penalty=add_penalty, remove_penalty=remove_penalty, mutation_context=mutation_context, make_decomposition_plots=make_decomposition_plots, originalProcessAvg=originalProcessAvg)
         
         # extract the global signatures and new signatures from the final_signatures dictionary
         globalsigs = final_signatures["globalsigs"]
@@ -1028,5 +1031,3 @@ def sigProfilerExtractor(input_type,
 
 
      
-
-
